@@ -16,31 +16,21 @@
 # =*= License: GPL-3+ =*=
 
 
-
-import os
-
-import cliapp
-
 import vmdb
 
 
-class ChrootPlugin(cliapp.Plugin):
-
+class ChrootPlugin(vmdb.Plugin):
     def enable(self):
         self.app.step_runners.add(ChrootStepRunner())
 
 
 class ChrootStepRunner(vmdb.StepRunnerInterface):
-
     def get_key_spec(self):
-        return {
-            'chroot': str,
-            'shell': str,
-        }
+        return {"chroot": str, "shell": str}
 
     def run(self, values, settings, state):
-        fs_tag = values['chroot']
-        shell = values['shell']
+        fs_tag = values["chroot"]
+        shell = values["shell"]
 
         mount_point = state.tags.get_builder_mount_point(fs_tag)
-        vmdb.runcmd_chroot(mount_point, ['sh', '-ec', shell])
+        vmdb.runcmd_chroot(mount_point, ["sh", "-ec", shell])
