@@ -140,10 +140,20 @@ class GrubStepRunner(vmdb.StepRunnerInterface):
         grub_target = "i386-pc"
         self.install_grub(values, settings, state, grub_package, grub_target)
 
+    def grub_ieee1275_variant(self, state):
+        variants = {
+            "amd64": "i386",
+            "ppc64": "powerpc",
+            "ppc64el": "powerpc",
+            "sparc": "sparc64"
+        }
+        logging.debug(f"grub plugin: state.arch={state.arch!r}")
+        return variants.get(state.arch, state.arch)
+
     def install_ieee1275(self, values, settings, state):
         vmdb.progress("Installing GRUB for IEEE1275")
         grub_package = "grub-ieee1275"
-        grub_target = "powerpc-ieee1275"
+        grub_target = f"{self.grub_ieee1275_variant(state)}-ieee1275"
         self.install_grub(values, settings, state, grub_package, grub_target)
 
     def install_grub(self, values, settings, state, grub_package, grub_target):
