@@ -103,6 +103,10 @@ class MountStepRunner(vmdb.StepRunnerInterface):
         if mount_point is None:
             return
 
+        resolv_conf = os.path.join(mount_point, "etc/resolv.conf")
+        if os.path.exists(resolv_conf):
+            os.remove(resolv_conf)
+
         try:
             vmdb.unmount(mount_point)
         except vmdb.NotMounted as e:
