@@ -30,13 +30,13 @@ class VirtualFilesystemMountPlugin(vmdb.Plugin):
 class VirtualFilesystemMountStepRunner(vmdb.StepRunnerInterface):
 
     virtuals = [
-        ["none", "/proc", "proc"],
-        ["none", "/dev", "devtmpfs"],
-        ["none", "/dev/pts", "devpts"],
-        ["none", "/dev/shm", "tmpfs"],
-        ["none", "/run", "tmpfs"],
-        ["none", "/run/lock", "tmpfs"],
-        ["none", "/sys", "sysfs"],
+        ["none", "/proc", ["-t", "proc"]],
+        ["/dev", "/dev", ["--bind"]],
+        ["none", "/dev/pts", ["-t","devpts"]],
+        ["none", "/dev/shm", ["-t","tmpfs"]],
+        ["none", "/run", ["-t","tmpfs"]],
+        ["none", "/run/lock", ["-t","tmpfs"]],
+        ["none", "/sys", ["-t","sysfs"]],
     ]
 
     def get_key_spec(self):
@@ -54,11 +54,14 @@ class VirtualFilesystemMountStepRunner(vmdb.StepRunnerInterface):
         if not hasattr(state, "virtuals"):
             state.virtuals = []
 
-        for device, mount_point, fstype in self.virtuals:
-            path = os.path.join(rootfs, "./" + mount_point)
+        for device, mount_point, opts in self.virtuals:
+            path = os.path.normpath(os.path.join(rootfs, "./" + mount_point))
+            if os.path.ismount(path):
+                logging.debug("already mounted: %s", path)
+                continue
             if not os.path.exists(path):
                 os.mkdir(path)
-            vmdb.runcmd(["mount", "-t", fstype, device, path])
+            vmdb.runcmd(["mount", device, path] + opts)
             state.virtuals.append(path)
         logging.debug("mounted virtuals: %r", state.virtuals)
 
